### About Functions

There are two types of functions, ones that are available for client-side [web] and server-side [node]. The ones for client-side are also available for server-side.

[Underscore Functions](http://documentcloud.github.com/underscore/) and these:

### capitalize

_String_ capitalize ( _String_ word) `[web]`

Capitalizes the first letter of string. Takes `word` argument as `String` and returns capitalized `String`.

Usage:

```javascript
  console.log(_.capitalize("fabio"));
  // Fabio
```

### contrastingColor

_String_ contrastingColor ( _String or Array_ color) `[web]`

This was also taken from somewhere on web... Gosh I wish I've saved the urls for reference... This function tells if you should use black or white on the background color. Takes the `color` argument as `String` or `Array` and color can be a hex `String` or an `Array` of RGB values 0-255 such as `[255, 255, 255]`. Returns `"000"` or `"fff"` for black or white.

Usage

```coffeescript
# can either use "fff" or "ffffff"
background = "ffffff" # white background should get black

result = _.contrastingColor("ffffff") # result is "000"
console.log result # "000"

```

### hexToRGBArray

_Array_ hexToRGBArray (_String_ color) `[web]`

Taken from somewhere on web I can't recall, this function converts hex color to RGB color Array. The argument should be a 3 digit or 6 digit hex color as `String`. Returns an `Array` with Red Green Blue values as `integer`. 

Usage:

```coffeescript
  hex = "f5664c"
  result = _.hexToRGBArray hex
  console.dir result # [245,102, 76]
```

### merge

_Object_ merge( _Object_ left, _Object_ right) `[web]`

Taken from [deepmerge package by nrf110](https://github.com/nrf110/deepmerge), a function that deeply merges objects. Function returns the merged `Object`. Takes two arguments, left `Object` and right `Object`. Right side overwrites left side.

```javascript
// Usage
var x = { foo: { bar: 3 },
  array: [ { does: 'work', too: [ 1, 2, 3 ] },{ really: 'yes' } ] }
var y = { foo: { baz: 4 },
  quux: 5,
  array: [ { does: 'work', too: [ 3,4, 5, 6 ] }, { really: 'ysee' } ] }

  _.merge(x,y)
// would result
{
    "foo": {
        "bar": 3,
        "baz": 4
    },
    "array": [
        {
            "does": "work",
            "too": [
                1,
                2,
                3,
                3,
                4,
                5,
                6
            ]
        },
        {
            "really": "ysee"
        }
    ],
    "quux": 5
}
```

### root

_String_ root() `[node]`

Gives the root directory of the node project, absolutely. Takes no arguments and returns the directory as `String`.

Usage:

```javascript
console.log(_.root());
// /home/logan/projects/npm-utilxi
```

### urlGetStatusCode

_void_ urlGetStatusCode ( _String_ url, _function_ callback( _int_ responseCode)) `[node]`

Makes a request to the web address and calls the callback function with the http response code.

Usage:

```coffeescript
    _.urlGetStatusCode "http://www.google.com/index.html", (code)->
        console.log code #200
    _.urlGetStatusCode "http://www.google.com/indexaaaa.html", (code)->
        console.log code #404
```


### urlGetStatusCodeReadable

_void_ urlGetStatusCodeReadable ( _String_ url, _function_ callback( _String_ responseString)) `[node]`

Makes a request to the web address and calls the callback function with the http response code.

Usage:

```coffeescript
    _.urlGetStatusCodeReadable "http://www.google.com/index.html", (code)->
        console.log code #OK
    _.urlGetStatusCodeReadable "http://www.google.com/indexaaaa.html", (code)->
        console.log code #Not Found
```

